import request from '@/utils/request'

// 查询停车位信息列表
export function listSpace(data) {
  return request({
    url: '/tSpace/list',
    method: 'post',
    data: data
  })
}

// 查询停车位信息详细
export function getSpace(id) {
  return request({
    url: '/tSpace/' + id,
    method: 'get'
  })
}

// 新增停车位信息
export function addSpace(data) {
  return request({
    url: '/tSpace',
    method: 'post',
    data: data
  })
}

// 修改停车位信息
export function updateSpace(data) {
  return request({
    url: '/tSpace',
    method: 'put',
    data: data
  })
}

// 删除停车位信息
export function delSpace(id) {
  return request({
    url: '/tSpace/' + id,
    method: 'delete'
  })
}

// 导入停车位信息
export function importData(data) {
  return request({
    url: '/tSpace/import',
    method: 'post',
    data: data
  })
}

// 导出停车位信息
export function exportSpace(data) {
  return request({
    url: '/tSpace/export',
    method: 'post',
    data: data
  })
}
